#include "php_gtk.h"
#if HAVE_PHP_GTK

#include "php_gdkpixbuf.h"

void php_gdk_pixbuf_register_constants(int module_number TSRMLS_DC)
{

	/* enum GdkColorspace */
	REGISTER_LONG_CONSTANT("GDK_COLORSPACE_RGB", GDK_COLORSPACE_RGB, CONST_CS | CONST_PERSISTENT);

	/* enum GdkPixbufAlphaMode */
	REGISTER_LONG_CONSTANT("GDK_PIXBUF_ALPHA_BILEVEL", GDK_PIXBUF_ALPHA_BILEVEL, CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("GDK_PIXBUF_ALPHA_FULL", GDK_PIXBUF_ALPHA_FULL, CONST_CS | CONST_PERSISTENT);

	/* enum GdkInterpType */
	REGISTER_LONG_CONSTANT("GDK_INTERP_NEAREST", GDK_INTERP_NEAREST, CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("GDK_INTERP_TILES", GDK_INTERP_TILES, CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("GDK_INTERP_BILINEAR", GDK_INTERP_BILINEAR, CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("GDK_INTERP_HYPER", GDK_INTERP_HYPER, CONST_CS | CONST_PERSISTENT);

	/* enum GdkPixbufFrameAction */
	REGISTER_LONG_CONSTANT("GDK_PIXBUF_FRAME_RETAIN", GDK_PIXBUF_FRAME_RETAIN, CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("GDK_PIXBUF_FRAME_DISPOSE", GDK_PIXBUF_FRAME_DISPOSE, CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("GDK_PIXBUF_FRAME_REVERT", GDK_PIXBUF_FRAME_REVERT, CONST_CS | CONST_PERSISTENT);
}

PHP_GTK_EXPORT_CE(gdk_pixbuf_ce);

/* object GdkPixbuf  */

PHP_FUNCTION(gdk_pixbuf_new)
{
	GdkColorspace colorspace;
	zval *php_colorspace = NULL;
	zend_bool has_alpha;
	long bits_per_sample, width, height;
	GdkPixbuf *wrapped_obj;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "Vbiii", &php_colorspace, &has_alpha, &bits_per_sample, &width, &height)) {
		php_gtk_invalidate(this_ptr);
		return;
	}

	if (php_colorspace && !php_gtk_get_simple_enum_value(php_colorspace, (gint *)&colorspace)) {
		php_gtk_invalidate(this_ptr);
		return;
	}

	wrapped_obj = (GdkPixbuf *)gdk_pixbuf_new(colorspace, (gboolean)has_alpha, (int)bits_per_sample, (int)width, (int)height);
	if (!wrapped_obj) {
		php_error(E_WARNING, "%s(): could not create GdkPixbuf object",
				  get_active_function_name(TSRMLS_C));
		php_gtk_invalidate(this_ptr);
		return;
	}

	php_gtk_set_object(this_ptr, wrapped_obj, le_gdk_pixbuf);

}


PHP_FUNCTION(gdk_pixbuf_unref)
{
	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	gdk_pixbuf_unref(PHP_GDK_PIXBUF_GET(this_ptr));
	RETURN_NULL();
}


PHP_FUNCTION(gdk_pixbuf_finalize)
{
	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	gdk_pixbuf_finalize(PHP_GDK_PIXBUF_GET(this_ptr));
	RETURN_NULL();
}


PHP_FUNCTION(gdk_pixbuf_get_colorspace)
{
	long php_retval;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	php_retval = gdk_pixbuf_get_colorspace(PHP_GDK_PIXBUF_GET(this_ptr));
	RETURN_LONG(php_retval);
}


PHP_FUNCTION(gdk_pixbuf_get_n_channels)
{
	long php_retval;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	php_retval = gdk_pixbuf_get_n_channels(PHP_GDK_PIXBUF_GET(this_ptr));
	RETURN_LONG(php_retval);
}


PHP_FUNCTION(gdk_pixbuf_get_has_alpha)
{
	gboolean php_retval;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	php_retval = gdk_pixbuf_get_has_alpha(PHP_GDK_PIXBUF_GET(this_ptr));
	RETURN_BOOL(php_retval);
}


PHP_FUNCTION(gdk_pixbuf_get_bits_per_sample)
{
	long php_retval;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	php_retval = gdk_pixbuf_get_bits_per_sample(PHP_GDK_PIXBUF_GET(this_ptr));
	RETURN_LONG(php_retval);
}


PHP_FUNCTION(gdk_pixbuf_get_pixels)
{
	gchar *ret;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	ret = gdk_pixbuf_get_pixels(PHP_GDK_PIXBUF_GET(this_ptr));
	if (ret) {
		RETURN_STRING(ret, 1);
		g_free(ret);
	} else
		RETURN_NULL();
}


PHP_FUNCTION(gdk_pixbuf_get_width)
{
	long php_retval;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	php_retval = gdk_pixbuf_get_width(PHP_GDK_PIXBUF_GET(this_ptr));
	RETURN_LONG(php_retval);
}


PHP_FUNCTION(gdk_pixbuf_get_height)
{
	long php_retval;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	php_retval = gdk_pixbuf_get_height(PHP_GDK_PIXBUF_GET(this_ptr));
	RETURN_LONG(php_retval);
}


PHP_FUNCTION(gdk_pixbuf_get_rowstride)
{
	long php_retval;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	php_retval = gdk_pixbuf_get_rowstride(PHP_GDK_PIXBUF_GET(this_ptr));
	RETURN_LONG(php_retval);
}


PHP_FUNCTION(gdk_pixbuf_copy)
{
	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), ""))
		return;

	PHP_GTK_SEPARATE_RETURN(return_value, php_gdk_pixbuf_new(gdk_pixbuf_copy(PHP_GDK_PIXBUF_GET(this_ptr))));
	return;
}


PHP_FUNCTION(gdk_pixbuf_add_alpha)
{
	zend_bool substitute_color;
	char r, g, b;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "bccc", &substitute_color, &r, &g, &b))
		return;

	PHP_GTK_SEPARATE_RETURN(return_value, php_gdk_pixbuf_new(gdk_pixbuf_add_alpha(PHP_GDK_PIXBUF_GET(this_ptr), (gboolean)substitute_color, r, g, b)));
	return;
}


PHP_FUNCTION(gdk_pixbuf_copy_area)
{
	long src_x, src_y, width, height, dest_x, dest_y;
	zval *dest_pixbuf;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "iiiiOii", &src_x, &src_y, &width, &height, &dest_pixbuf, gdk_pixbuf_ce, &dest_x, &dest_y))
		return;

	gdk_pixbuf_copy_area(PHP_GDK_PIXBUF_GET(this_ptr), (int)src_x, (int)src_y, (int)width, (int)height, PHP_GDK_PIXBUF_GET(dest_pixbuf), (int)dest_x, (int)dest_y);
	RETURN_NULL();
}


PHP_FUNCTION(gdk_pixbuf_render_threshold_alpha)
{
	zval *bitmap;
	long src_x, src_y, dest_x, dest_y, width, height, alpha_threshold;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "Oiiiiiii", &bitmap, gdk_bitmap_ce, &src_x, &src_y, &dest_x, &dest_y, &width, &height, &alpha_threshold))
		return;

	gdk_pixbuf_render_threshold_alpha(PHP_GDK_PIXBUF_GET(this_ptr), PHP_GDK_BITMAP_GET(bitmap), (int)src_x, (int)src_y, (int)dest_x, (int)dest_y, (int)width, (int)height, (int)alpha_threshold);
	RETURN_NULL();
}


PHP_FUNCTION(gdk_pixbuf_render_to_drawable)
{
	GdkDrawable *drawable;
	zval *php_drawable, *gc, *php_dither = NULL;
	long src_x, src_y, dest_x, dest_y, width, height, x_dither, y_dither;
	GdkRgbDither dither;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "VOiiiiiiVii", &php_drawable, &gc, gdk_gc_ce, &src_x, &src_y, &dest_x, &dest_y, &width, &height, &php_dither, &x_dither, &y_dither))
		return;

	if (php_gtk_check_class(php_drawable, gdk_window_ce))
							drawable = (GdkDrawable *)PHP_GDK_WINDOW_GET(php_drawable);
						else if(php_gtk_check_class(php_drawable, gdk_pixmap_ce))
							drawable = (GdkDrawable *)PHP_GDK_PIXMAP_GET(php_drawable);
						else if(php_gtk_check_class(php_drawable, gdk_bitmap_ce))
							drawable = (GdkDrawable *)PHP_GDK_BITMAP_GET(php_drawable);
						else {
								php_error(E_WARNING, "%s() expects the drawable to be GdkWindow, GdkPixmap, or GdkBitmap", get_active_function_name(TSRMLS_C));
								return;
						}
					if (php_dither && !php_gtk_get_enum_value(GTK_TYPE_GDK_RGB_DITHER, php_dither, (gint *)&dither)) {
		return;
	}

	gdk_pixbuf_render_to_drawable(PHP_GDK_PIXBUF_GET(this_ptr), drawable, PHP_GDK_GC_GET(gc), (int)src_x, (int)src_y, (int)dest_x, (int)dest_y, (int)width, (int)height, dither, (int)x_dither, (int)y_dither);
	RETURN_NULL();
}


PHP_FUNCTION(gdk_pixbuf_render_to_drawable_alpha)
{
	GdkDrawable *drawable;
	zval *php_drawable, *php_alpha_mode = NULL, *php_dither = NULL;
	long src_x, src_y, dest_x, dest_y, width, height, alpha_threshold, x_dither, y_dither;
	GdkPixbufAlphaMode alpha_mode;
	GdkRgbDither dither;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "ViiiiiiViVii", &php_drawable, &src_x, &src_y, &dest_x, &dest_y, &width, &height, &php_alpha_mode, &alpha_threshold, &php_dither, &x_dither, &y_dither))
		return;

	if (php_gtk_check_class(php_drawable, gdk_window_ce))
							drawable = (GdkDrawable *)PHP_GDK_WINDOW_GET(php_drawable);
						else if(php_gtk_check_class(php_drawable, gdk_pixmap_ce))
							drawable = (GdkDrawable *)PHP_GDK_PIXMAP_GET(php_drawable);
						else if(php_gtk_check_class(php_drawable, gdk_bitmap_ce))
							drawable = (GdkDrawable *)PHP_GDK_BITMAP_GET(php_drawable);
						else {
								php_error(E_WARNING, "%s() expects the drawable to be GdkWindow, GdkPixmap, or GdkBitmap", get_active_function_name(TSRMLS_C));
								return;
						}
					if (php_alpha_mode && !php_gtk_get_simple_enum_value(php_alpha_mode, (gint *)&alpha_mode)) {
		return;
	}

	if (php_dither && !php_gtk_get_enum_value(GTK_TYPE_GDK_RGB_DITHER, php_dither, (gint *)&dither)) {
		return;
	}

	gdk_pixbuf_render_to_drawable_alpha(PHP_GDK_PIXBUF_GET(this_ptr), drawable, (int)src_x, (int)src_y, (int)dest_x, (int)dest_y, (int)width, (int)height, alpha_mode, (int)alpha_threshold, dither, (int)x_dither, (int)y_dither);
	RETURN_NULL();
}

PHP_FUNCTION(gdk_pixbuf_render_pixmap_and_mask)
{
	int alpha_threshold;
	GdkPixmap *pixmap;
	GdkBitmap *mask;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "i", &alpha_threshold))
		return;

	gdk_pixbuf_render_pixmap_and_mask(PHP_GDK_PIXBUF_GET(this_ptr), &pixmap,
									  &mask, alpha_threshold);

	*return_value = *php_gtk_build_value("(NN)", php_gdk_pixmap_new(pixmap),
										 php_gdk_bitmap_new(mask));
}

PHP_FUNCTION(gdk_pixbuf_get_from_drawable)
{
	GdkDrawable *src;
	zval *php_src, *cmap;
	long src_x, src_y, dest_x, dest_y, width, height;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "VOiiiiii", &php_src, &cmap, gdk_colormap_ce, &src_x, &src_y, &dest_x, &dest_y, &width, &height))
		return;

	if (php_gtk_check_class(php_src, gdk_window_ce))
							src = (GdkDrawable *)PHP_GDK_WINDOW_GET(php_src);
						else if(php_gtk_check_class(php_src, gdk_pixmap_ce))
							src = (GdkDrawable *)PHP_GDK_PIXMAP_GET(php_src);
						else if(php_gtk_check_class(php_src, gdk_bitmap_ce))
							src = (GdkDrawable *)PHP_GDK_BITMAP_GET(php_src);
						else {
								php_error(E_WARNING, "%s() expects the drawable to be GdkWindow, GdkPixmap, or GdkBitmap", get_active_function_name(TSRMLS_C));
								return;
						}
					PHP_GTK_SEPARATE_RETURN(return_value, php_gdk_pixbuf_new(gdk_pixbuf_get_from_drawable(PHP_GDK_PIXBUF_GET(this_ptr), src, PHP_GDK_COLORMAP_GET(cmap), (int)src_x, (int)src_y, (int)dest_x, (int)dest_y, (int)width, (int)height)));
	return;
}


PHP_FUNCTION(gdk_pixbuf_scale)
{
	zval *dest, *php_interp_type = NULL;
	long dest_x, dest_y, dest_width, dest_height;
	double offset_x, offset_y, scale_x, scale_y;
	GdkInterpType interp_type;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "OiiiiddddV", &dest, gdk_pixbuf_ce, &dest_x, &dest_y, &dest_width, &dest_height, &offset_x, &offset_y, &scale_x, &scale_y, &php_interp_type))
		return;

	if (php_interp_type && !php_gtk_get_simple_enum_value(php_interp_type, (gint *)&interp_type)) {
		return;
	}

	gdk_pixbuf_scale(PHP_GDK_PIXBUF_GET(this_ptr), PHP_GDK_PIXBUF_GET(dest), (int)dest_x, (int)dest_y, (int)dest_width, (int)dest_height, offset_x, offset_y, scale_x, scale_y, interp_type);
	RETURN_NULL();
}


PHP_FUNCTION(gdk_pixbuf_composite)
{
	zval *dest, *php_interp_type = NULL;
	long dest_x, dest_y, dest_width, dest_height, overall_alpha;
	double offset_x, offset_y, scale_x, scale_y;
	GdkInterpType interp_type;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "OiiiiddddVi", &dest, gdk_pixbuf_ce, &dest_x, &dest_y, &dest_width, &dest_height, &offset_x, &offset_y, &scale_x, &scale_y, &php_interp_type, &overall_alpha))
		return;

	if (php_interp_type && !php_gtk_get_simple_enum_value(php_interp_type, (gint *)&interp_type)) {
		return;
	}

	gdk_pixbuf_composite(PHP_GDK_PIXBUF_GET(this_ptr), PHP_GDK_PIXBUF_GET(dest), (int)dest_x, (int)dest_y, (int)dest_width, (int)dest_height, offset_x, offset_y, scale_x, scale_y, interp_type, (int)overall_alpha);
	RETURN_NULL();
}


PHP_FUNCTION(gdk_pixbuf_composite_color)
{
	zval *dest, *php_interp_type = NULL;
	long dest_x, dest_y, dest_width, dest_height, overall_alpha, check_x, check_y, check_size, color1, color2;
	double offset_x, offset_y, scale_x, scale_y;
	GdkInterpType interp_type;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "OiiiiddddViiiiii", &dest, gdk_pixbuf_ce, &dest_x, &dest_y, &dest_width, &dest_height, &offset_x, &offset_y, &scale_x, &scale_y, &php_interp_type, &overall_alpha, &check_x, &check_y, &check_size, &color1, &color2))
		return;

	if (php_interp_type && !php_gtk_get_simple_enum_value(php_interp_type, (gint *)&interp_type)) {
		return;
	}

	gdk_pixbuf_composite_color(PHP_GDK_PIXBUF_GET(this_ptr), PHP_GDK_PIXBUF_GET(dest), (int)dest_x, (int)dest_y, (int)dest_width, (int)dest_height, offset_x, offset_y, scale_x, scale_y, interp_type, (int)overall_alpha, (int)check_x, (int)check_y, (int)check_size, (guint32)color1, (guint32)color2);
	RETURN_NULL();
}


PHP_FUNCTION(gdk_pixbuf_scale_simple)
{
	long dest_width, dest_height;
	GdkInterpType interp_type;
	zval *php_interp_type = NULL;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "iiV", &dest_width, &dest_height, &php_interp_type))
		return;

	if (php_interp_type && !php_gtk_get_simple_enum_value(php_interp_type, (gint *)&interp_type)) {
		return;
	}

	PHP_GTK_SEPARATE_RETURN(return_value, php_gdk_pixbuf_new(gdk_pixbuf_scale_simple(PHP_GDK_PIXBUF_GET(this_ptr), (int)dest_width, (int)dest_height, interp_type)));
	return;
}


PHP_FUNCTION(gdk_pixbuf_composite_color_simple)
{
	long dest_width, dest_height, overall_alpha, check_size, color1, color2;
	GdkInterpType interp_type;
	zval *php_interp_type = NULL;

	NOT_STATIC_METHOD();

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "iiViiii", &dest_width, &dest_height, &php_interp_type, &overall_alpha, &check_size, &color1, &color2))
		return;

	if (php_interp_type && !php_gtk_get_simple_enum_value(php_interp_type, (gint *)&interp_type)) {
		return;
	}

	PHP_GTK_SEPARATE_RETURN(return_value, php_gdk_pixbuf_new(gdk_pixbuf_composite_color_simple(PHP_GDK_PIXBUF_GET(this_ptr), (int)dest_width, (int)dest_height, interp_type, (int)overall_alpha, (int)check_size, (guint32)color1, (guint32)color2)));
	return;
}


PHP_FUNCTION(gdk_pixbuf_new_from_file)
{
	char *filename;

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "s", &filename))
		return;

	PHP_GTK_SEPARATE_RETURN(return_value, php_gdk_pixbuf_new(gdk_pixbuf_new_from_file(filename)));
	return;
}

PHP_FUNCTION(gdk_pixbuf_new_from_data)
{
	zval *data;
	GdkColorspace colorspace;
	zval *php_colorspace = NULL;
	zend_bool has_alpha;
	long bits_per_sample, width, height, rowstride;

	if (!php_gtk_parse_args(ZEND_NUM_ARGS(), "VVbiiii", &data, &php_colorspace, &has_alpha, &bits_per_sample, &width, &height, &rowstride))
		return;

	convert_to_string(data);
	zval_add_ref(&data);

	if (php_colorspace && !php_gtk_get_simple_enum_value(php_colorspace, (gint *)&colorspace)) {
		return;
	}

	PHP_GTK_SEPARATE_RETURN(return_value, php_gdk_pixbuf_new(gdk_pixbuf_new_from_data(Z_STRVAL_P(data), colorspace, (gboolean)has_alpha, (int)bits_per_sample, (int)width, (int)height, (int)rowstride, (GdkPixbufDestroyNotify)php_gtk_destroy_notify, data)));
}

static function_entry php_gdk_pixbuf_functions[] = {
	{"GdkPixbuf",	PHP_FN(gdk_pixbuf_new),	NULL},
	{"gdkpixbuf",	PHP_FN(gdk_pixbuf_new),	NULL},
	{"unref",	PHP_FN(gdk_pixbuf_unref),	NULL},
	{"finalize",	PHP_FN(gdk_pixbuf_finalize),	NULL},
	{"get_colorspace",	PHP_FN(gdk_pixbuf_get_colorspace),	NULL},
	{"get_n_channels",	PHP_FN(gdk_pixbuf_get_n_channels),	NULL},
	{"get_has_alpha",	PHP_FN(gdk_pixbuf_get_has_alpha),	NULL},
	{"get_bits_per_sample",	PHP_FN(gdk_pixbuf_get_bits_per_sample),	NULL},
	{"get_pixels",	PHP_FN(gdk_pixbuf_get_pixels),	NULL},
	{"get_width",	PHP_FN(gdk_pixbuf_get_width),	NULL},
	{"get_height",	PHP_FN(gdk_pixbuf_get_height),	NULL},
	{"get_rowstride",	PHP_FN(gdk_pixbuf_get_rowstride),	NULL},
	{"copy",	PHP_FN(gdk_pixbuf_copy),	NULL},
	{"add_alpha",	PHP_FN(gdk_pixbuf_add_alpha),	NULL},
	{"copy_area",	PHP_FN(gdk_pixbuf_copy_area),	NULL},
	{"render_threshold_alpha",	PHP_FN(gdk_pixbuf_render_threshold_alpha),	NULL},
	{"render_to_drawable",	PHP_FN(gdk_pixbuf_render_to_drawable),	NULL},
	{"render_to_drawable_alpha",	PHP_FN(gdk_pixbuf_render_to_drawable_alpha),	NULL},
	{"render_pixmap_and_mask",	PHP_FN(gdk_pixbuf_render_pixmap_and_mask),	NULL},
	{"get_from_drawable",	PHP_FN(gdk_pixbuf_get_from_drawable),	NULL},
	{"scale",	PHP_FN(gdk_pixbuf_scale),	NULL},
	{"composite",	PHP_FN(gdk_pixbuf_composite),	NULL},
	{"composite_color",	PHP_FN(gdk_pixbuf_composite_color),	NULL},
	{"scale_simple",	PHP_FN(gdk_pixbuf_scale_simple),	NULL},
	{"composite_color_simple",	PHP_FN(gdk_pixbuf_composite_color_simple),	NULL},
	{"new_from_file",	PHP_FN(gdk_pixbuf_new_from_file),	NULL},
	{"new_from_data",	PHP_FN(gdk_pixbuf_new_from_data),	NULL},
	{NULL, NULL, NULL}
};


void php_gdk_pixbuf_register_classes(void)
{
	zend_class_entry ce;
	TSRMLS_FETCH();

	INIT_OVERLOADED_CLASS_ENTRY(ce, "GdkPixbuf", php_gdk_pixbuf_functions, NULL, NULL, php_gtk_set_property);
	gdk_pixbuf_ce = zend_register_internal_class_ex(&ce, NULL, NULL TSRMLS_CC);


}

#endif /* HAVE_PHP_GTK */
